@@ -3,6 +3,7 @@ from functools import wraps
 from flask import g, jsonify
 
 from ForMark.ForLog import ForLog
+from ForMark.ForString import is_none_str
 
 
 def get_params(params=None):
@@ -13,11 +14,18 @@ def get_params(params=None):
                 if not g.params:
                     return jsonify(success=False, msg='缺少必填参数', code='10001')
                 for item in params.items():
-                    key = g.params.get(item[0], None)
-                    ForLog.show("参数",key)
-                    if key is None:
+                    value = g.params.get(item[0], None)
+                    ForLog.show("参数", value)
+                    if value is None:
                         return jsonify(success=False, msg=item[1], code='10001')
-                    g.setdefault(item[0], key)
+                    if len(item) > 2:
+                        nullable = g.params.get(item[2], None)
+                        if nullable and is_none_str(value):
+                            return jsonify(success=False, msg=item[1], code='10001')
+
+                    g.setdefault(item[0], value)
             return func(*args, **kwargs)
+
         return inner
+
     return wrapper
